@@ -98,8 +98,8 @@ trainingaccuracy <- function(f,test="all")
   me <- mean(res,na.rm=TRUE)
   mse <- mean(res^2,na.rm=TRUE)
   mae <- mean(abs(res),na.rm=TRUE)
-  mape <- mean(100*abs(pe),na.rm=TRUE)
-  mpe <-  mean(100*pe,na.rm=TRUE)
+  mape <- mean(abs(pe),na.rm=TRUE)
+  mpe <-  mean(pe,na.rm=TRUE)
   out <- c(me,sqrt(mse),mae,mpe,mape)
   names(out) <- c("ME","RMSE","MAE","MPE","MAPE")
 
