@@ -1,5 +1,5 @@
 
-fitSpecificTBATS <- function(y, use.box.cox, use.beta, use.damping, seasonal.periods=NULL, k.vector=NULL, starting.params=NULL, x.nought=NULL, ar.coefs=NULL, ma.coefs=NULL, init.box.cox=NULL) {
+fitSpecificTBATS <- function(y, use.box.cox, use.beta, use.damping, seasonal.periods=NULL, k.vector=NULL, starting.params=NULL, x.nought=NULL, ar.coefs=NULL, ma.coefs=NULL, init.box.cox=NULL, bc.lower=0, bc.upper=1) {
 	#print(k.vector)
 	if(!is.null(seasonal.periods)) {
 		seasonal.periods <- sort(seasonal.periods)
@@ -235,7 +235,7 @@ fitSpecificTBATS <- function(y, use.box.cox, use.beta, use.damping, seasonal.per
 		#x.nought.untransformed <- InvBoxCox(x.nought, lambda=lambda)
 		assign("x.nought.untransformed", InvBoxCox(x.nought, lambda=lambda), envir=opt.env)
 		#Optimise the likelihood function
-		optim.like <- optim(par=param.vector$vect, fn=calcLikelihoodTBATS, method="Nelder-Mead", opt.env=opt.env, use.beta=use.beta, use.small.phi=use.damping, seasonal.periods=seasonal.periods, param.control=param.vector$control, p=p, q=q, tau=tau, control=list(maxit=(100*length(param.vector$vect)^2), parscale=par.scale))
+		optim.like <- optim(par=param.vector$vect, fn=calcLikelihoodTBATS, method="Nelder-Mead", opt.env=opt.env, use.beta=use.beta, use.small.phi=use.damping, seasonal.periods=seasonal.periods, param.control=param.vector$control, p=p, q=q, tau=tau, bc.lower=bc.lower, bc.upper=bc.upper, control=list(maxit=(100*length(param.vector$vect)^2), parscale=par.scale))
 		#Get the parameters out of the param.vector
 		paramz <- unParameteriseTBATS(optim.like$par, param.vector$control)
 		lambda <- paramz$lambda
@@ -369,13 +369,13 @@ fitSpecificTBATS <- function(y, use.box.cox, use.beta, use.damping, seasonal.per
 		#print("@@@@AIC:")
 		#print(aic)	
 		#print("@@@@@@@")
-	#}
+	#}	
 	return(model.for.output)
 }
 
 
 
-calcLikelihoodTBATS <- function(param.vector, opt.env, use.beta, use.small.phi, seasonal.periods, param.control, p=0, q=0, tau=0) {
+calcLikelihoodTBATS <- function(param.vector, opt.env, use.beta, use.small.phi, seasonal.periods, param.control, p=0, q=0, tau=0, bc.lower=0, bc.upper=1) {
 	#param vector should be as follows: Box-Cox.parameter, alpha, beta, small.phi, gamma.vector, ar.coefs, ma.coefs 
 	#Put the components of the param.vector into meaningful individual variables
 	#print("&&&&&&&&&&& Param Vector:")
@@ -434,7 +434,7 @@ calcLikelihoodTBATS <- function(param.vector, opt.env, use.beta, use.small.phi,
 	assign("D", (opt.env$F - opt.env$g %*% opt.env$w.transpose), envir=opt.env)
 	#print("two 2 - AFTER")
 	#print(param.vector)
-	if(checkAdmissibility(opt.env, box.cox=box.cox.parameter, small.phi=small.phi, ar.coefs=ar.coefs, ma.coefs=ma.coefs, tau=sum(seasonal.periods))) {
+	if(checkAdmissibility(opt.env, box.cox=box.cox.parameter, small.phi=small.phi, ar.coefs=ar.coefs, ma.coefs=ma.coefs, tau=sum(seasonal.periods), bc.lower=bc.lower, bc.upper=bc.upper)) {
 		return(log.likelihood)
 	} else {
 		return(10^20)
